@echo off

:: ============================================================================
:: Variablen zur Steuerung der nachfolgenden Batches
set _SQS_FORCE=
set _SQS_SILENT=
set _SQS_MAX=

:: ============================================================================
:: Variablen fr die Steuerung der Applikation
::   fr die Konfiguration der Dienste
set SQS_SERVICE_USER=
set SQS_PW=
set SQS_DEPENDENCIES=
set SQS_AUTO_START=
set SQS_EVT_LEVEL=

: Variable fr alle nicht analysierbaren Parameter
set _SQS_ADD_PARAMS=
set PSQS_HOSTNAME_POLICY=
set PSQS_CORBA_LOCS=
set _SQS_USE_NO_CONTEXT=
set _SQS_NO_GUI_SELECT=
set "CheckDependencies="
if exist "Dependencies\DependenciesGui.exe" set "CheckDependencies=0"

: Lokal bentigte Variablen
set _SET=
set _PREFIX=
:: ============================================================================
:: z. Zt. bekannte Servertypen diese knnen mit "-Server" bergeben werden.
:: Wird die Liste manipuliert muss auch die Anzahl korrekt gesetzt werden.
:: ============================================================================
set _SQS_SERVER_TYPES=MS/AS/API/IMP_XML/LM
set _SQS_ANZ_SERVER_TYPES=5

:: ============================================================================
:: Vom Betriebssystem unterstuetzte Architektur herausfinden und entsprechende
:: Variablen setzen
set _SQS_ARCH=AMD64
set _64DIR=\x64
set _SQS_IS_64BIT=1
IF "%PROCESSOR_ARCHITECTURE%" NEQ "%_SQS_ARCH%" (
   if not defined PROCESSOR_ARCHITEW6432 set _64DIR=&set _SQS_IS_64BIT=&set _SQS_ARCH=x86
)

:: ============================================================================
:: Iteriere ber alle bergebenen Parameter
set SHOW_PARAMS=%*
set /a PCOUNT=0
for %%i in (%*) do call :Analyse %%i

if defined _SQS_VAD set _SQS_VA=1

::if defined _SQS_TEMP_LANG set _SQS_LANGUAGE=%_SQS_TEMP_LANG%
:: Ergebnisausgabe, bei der auf Quotes geachtet werden muss,
:: " werden durch ' ersetzt
if defined SHOW_PARAMS set SHOW_PARAMS=%SHOW_PARAMS:"='%
call :Debug ": Eingabe      : '%SHOW_PARAMS%'" RMQuotes
set SHOW_PARAMS=%_SQS_ADD_PARAMS%&
if defined SHOW_PARAMS set SHOW_PARAMS=%SHOW_PARAMS:"='%
call :Debug ": Restparameter: '%SHOW_PARAMS%'" RMQuotes

if not defined _BOOTSTRAP call :CheckProcessNumber

goto :EOF

:CheckProcessNumber
	if not defined _SQS_ONLY_ONE goto ALL
	if "%_SQS_ONLY_ONE%" EQU "MS" goto ONLY_ONE_ALLOWED

	:: ============================================================================
	:: Checke, ob _SQS_ONLY_ONE auf einen gltigen Wert gesetzt wurde:
	:: ============================================================================
	call :CheckServerType _TYP_FOUND
	if not defined _TYP_FOUND (
		set _SQS_WRONG_SERVERTYPE=1
		set _SQS_SERVERTYPE=%_SQS_ONLY_ONE%
		call :Warning Hint: Server '%_SQS_ONLY_ONE%' is not a valid servertype.
		goto ALL
	)
	if not defined _SQS_PROCESS_NUMBER call :ProcessNumberHint&goto ONLY_ONE_ALLOWED
	call :RemoveLeadingZeros %_SQS_PROCESS_NUMBER% _N_
	call :CheckNumber %_N_% _OK_
	call :Debug : Input number: '%_SQS_PROCESS_NUMBER%' Output '%_N_%' (ok='%_OK_%')
	if defined _OK_ (
		goto :EOF
	) else (
		goto ONLY_ONE_ALLOWED
	)
	
	:: Falls nichts zutrifft lsche die abhaengigen Variablen
	:: ============================================================================
	:ALL
	set _SQS_ONLY_ONE=
	
	:ONLY_ONE_ALLOWED
	set _SQS_PROCESS_NUMBER=
	set PSQS_PROCESS_NUMBER=
goto :EOF

:ProcessNumberHint
	if defined NO_PN_HINT goto :EOF
	call :Warning "Hint: No valid process number was given to server '%_SQS_ONLY_ONE%'" RMQuotes
	call :Warning "      you can give '-ProcessNumber [n]' to the call, to set this number," RMQuotes
	call :Warning "      where [n] should be a number greater 0." RMQuotes
goto :EOF

:ProcessNumberError
	if defined NO_PN_HINT goto :EOF
	call :Warning "Hint: Given process number '%_SQS_PROCESS_NUMBER%' was wrong." RMQuotes
	call :Warning "      The value has to be greater 0." RMQuotes
goto :EOF

:: ============================================================================
:: ============================================================================
:: Startbereich fr lokale Prozeduren
:: ============================================================================
:: ============================================================================

:CheckServerType
	set %~1=
	for /d %%i in (%_SQS_SERVER_TYPES:/= %) do if "%%i" EQU "%_SQS_ONLY_ONE%" set %~1=%%i
goto :EOF

:CheckNumber
	:: Nummer muss grer 0 sein
	set %~2=
	:: echo %~0: %*
	set /a _NUMBER=%~1
	if not defined _NUMBER set _SQS_WRONG_NUMBER=1&call :ProcessNumberError&goto :EOF
	if %_NUMBER% LEQ 0 set _SQS_WRONG_NUMBER=1&call :ProcessNumberError&goto :EOF
	set PSQS_PROCESS_NUMBER=-ProcessNumber %~1
	set _SQS_PROCESS_NUMBER=%~1
	set %~2=1
goto :EOF

:CheckIfOption
	:: ============================================================================
	:: Stellt fest, ob der bergebene Parameter eine Option ist:
	:: Ein bergebener Wert ist eine Option, wenn er mit einem einzigen Dash ('-')
	:: beginnt und das soll hier erkannt und in der Variablen _IS_OPTION gemerkt 
	:: werden. 
	:: ============================================================================
	:: call :DebugHeader %0 %*
	set _IS_OPTION=
	set _VALUE=%~1
	if not defined _VALUE goto :EOF

	if "%_VALUE:~0,2%" EQU "--" goto :EOF
	if "%_VALUE:~0,1%" EQU "-" set _IS_OPTION=1
goto :EOF

:CheckVarName
	:: ============================================================================
	:: Stellt fest, ob die bergebene Variable einen fhrenden Unterstrich hat
	:: und eliminiert diesen, falls gewnscht (=> NO_UNDERSCORE ist definiert).
	:: ============================================================================
	:: call :DebugHeader %0 %*
	if not defined NO_UNDERSCORE goto :EOF
	:: Beide Parameter mssen gesetzt sein.
	set _VALUE=%~1
	set _VALUE2=%~2
	if not defined _VALUE  goto :EOF
	if not defined _VALUE2 goto :EOF
	if "%_VALUE:~0,1%" EQU "_" set %~2=%_VALUE:~1,100%
goto :EOF

:: ============================================================================
:: Analyseprozedur:
:Analyse
	set /a PCOUNT+=1
	if defined SKIP%PCOUNT% call :Debug Skipping '%~1'&goto :EOF
	:: ============================================================================
	:: Falls in dem vorangegangen Aufruf ein Parameter gefunden wurde, setze 
	:: jetzt den Wert dieses Parameters. Wenn es wieder eine Option ist setze den 
	:: Wert auf 1
	:: ============================================================================
	call :CheckIfOption %1
	call :CheckVarName %_SET% _SET
	:: echo _SET = %_SET%
	if defined _SET if defined _IS_OPTION set %_SET%=1&set _SET=
	if defined _SET set %_SET%=%_PREFIX%%~1&set _SET=&set _PREFIX=&goto EOP

	if defined _BOOTSTRAP goto ONLY_BOOTSTRAP
	:: ============================================================================
	:: Erkennen der bekannten Parameter
	:: ============================================================================
	:: die offiziellen Skript Parameter:
	:: ============================================================================
	:ONLY_BOOTSTRAP
	if /i %1 EQU -fi			 	goto EOP
	if /i %1 EQU -help			 	set _SET=_SQS_HELP_ONLY&		goto EOP
	if /i %1 EQU -h				 	set _SQS_HELP_ONLY=1&			goto EOP
	if /i %1 EQU /?				 	set _SQS_HELP_ONLY=1&			goto EOP
	if /i %1 EQU -Debug		 		set _SET=_SQS_DEBUG&			goto EOP
	if /i %1 EQU -d				 	set _SQS_DEBUG=1&				goto EOP
	if /i %1 EQU -Silent		 	set _SET=_SQS_SILENT&			goto EOP
	if /i %1 EQU -s				 	set _SQS_SILENT=1&				goto EOP
	if /i %1 EQU -Force 			set _SET=_SQS_FORCE&			goto EOP
	if /i %1 EQU -f 				set _SQS_FORCE=1&				goto EOP
	if /i %1 EQU -ForceKILL			set _SET=_SQS_FORCE_KILL&		goto EOP
	if /i %1 EQU -Max				set _SET=_SQS_MAX&				goto EOP
	if /i %1 EQU -Warning			set _SET=_SQS_SHOW_WARNIG&		goto EOP
	if /i %1 EQU -Server			set _SET=_SQS_ONLY_ONE&			goto EOP
	if /i %1 EQU -n					set _SQS_ECHO=echo&				goto EOP
	if /i %1 EQU -e					set _SQS_ECHO=echo&set _SQS_ECHO_AND_RUN=1&goto EOP
	if /i %1 EQU -c					set _SQS_CONSOLE=1&				goto EOP
	if /i %1 EQU -t					set _SQS_TEST=1&				goto EOP
	if /i %1 EQU -i					set _SQS_TAKE_EXISTING_IT=1&	goto EOP
	if /i %1 EQU -va				set _SQS_VA=1&					goto EOP
	if /i %1 EQU -vad				set _SQS_VAD=1&					goto EOP
	if /i %1 EQU -interactive		set _SQS_INTERACTIVE=1&			goto EOP
	if /i %1 EQU -no_interaction	set _SQS_NO_INTERACTION=1&		goto EOP
	if /i %1 EQU -UseDefaultDomain	set _SQS_USE_DEFAULT_DOMAIN=1&	goto EOP
	if /i %1 EQU -Header			set _SQS_SHOW_HEADER=1&			goto EOP
	if /i %1 EQU -me				set _SQS_MYSELF=1&				goto EOP
	if /i %1 EQU -DeleteORBEnv		set _SQS_DELETE_ORB_ENV=1&		goto EOP
	if /i %1 EQU -NoGUISelect		set _SQS_NO_GUI_SELECT=1&		goto EOP
	if /i %1 EQU -UseShortPath		set _SQS_USE_SHORT_PATH=1&		goto EOP
	if /i %1 EQU -PrependPath		set _SQS_PREPEND_PATH=1&		goto EOP
	if /i %1 EQU -AppendPath		set _SQS_APPEND_PATH=1&			goto EOP
	if /i %1 EQU -Async				set _SQS_ASYNCHRON=1&			goto EOP
	if /i %1 EQU -NoAsync			set _SQS_ASYNCHRON=&			goto EOP

	:: die offiziellen Process Parameter:
	:: ============================================================================
	if /i %1 EQU -ServerContext		set _SET=SQS_SERVER_CONTEXT&	goto EOP
	if /i %1 EQU -NoContext			set _SQS_USE_NO_CONTEXT=1&		goto EOP
	if /i %1 EQU -AC				set _SQS_CALLED_BY_AC=1&		goto EOP
	if /i %1 EQU -APIVersion		set _SET=_SQS_API_VERSION&		goto EOP
	if /i %1 EQU -LocalConfigDir 	    set _SET=_SQS_CONFIG_DIR&     	goto EOP
	if defined _BOOTSTRAP goto EOP
	if /i %1 EQU -DBHost	 		set _SET=_SQS_DB_HOST&			goto EOP
	if /i %1 EQU -DBName	 		set _SET=_SQS_DB_NAME&			goto EOP
	if /i %1 EQU -DBConfigFile		set _SET=SQS_DB_CONFIG_FILE&	goto EOP
	if /i %1 EQU -NoDB				set _SQS_NO_DB=1&				goto EOP
	if /i %1 EQU -UseUpdateConfig	set _SQS_USE_UPDATE_CONFIG=1&	goto EOP
	if /i %1 EQU -TargetDir			set _SET=_SQS_TARGET_DIR&		goto EOP
	if /i %1 EQU -Language 			set _SET=_SQS_TEMP_LANG&		goto EOP
	if /i %1 EQU -ProcessNumber		set _SET=_SQS_PROCESS_NUMBER&	goto EOP
	if /i %1 EQU -LicenseFile		set _SET=_SQS_LICENSE_FILE&		goto EOP
	if /i %1 EQU -VerboseMode		set _SET=SQS_VERBOSE_MODE&		goto EOP
	if /i %1 EQU -VerboseLevel		set _SET=SQS_VERBOSE_LEVEL&		goto EOP
	if /i %1 EQU -LogFile			set _SET=_SQS_LOG_FILE&			goto EOP
	if /i %1 EQU -AppendToLogFile	set _SET=_SQS_APPEND_TO_LOG_FILE&goto EOP
	if /i %1 EQU -NoLogFile			set _SET=_SQS_NO_LOG_FILE&		goto EOP
	if /i %1 EQU -JavaHome			set _SET=SQS_JAVA_HOME&set _CALLER_NEED_JAVA=1&goto EOP
	if /i %1 EQU -JavaMinVersion	set _SET=_SQS_JAVA_MIN_VERSION&set _CALLER_NEED_JAVA=1&goto EOP
	if /i %1 EQU -TSSys				set _SET=_SQS_TSSYS&			goto EOP
	if /i %1 EQU -HostNameToLower	set SQS_NO_HOSTNAME_CONVERTION=0&goto EOP
	if /i %1 EQU -NoCorba			set _SQS_NO_CORBA=1&			goto EOP
	if /i %1 EQU -NoDomainCheck		set SQS_NO_DOMAIN_CHECK=1&		goto EOP
	if /i %1 EQU -CorbaHost			set _SET=_SQS_CORBA_HOST&		goto EOP
	if /i %1 EQU -CorbaHostDomain	set _SET=_SQS_CORBA_HOST_DOM&	goto EOP
	if /i %1 EQU -CorbaBasePort		set _SET=_SQS_CORBA_BASE_PORT&	goto EOP
	if /i %1 EQU -CorbaPort			set _SET=_SQS_CORBA_BASE_PORT&	goto EOP
	if /i %1 EQU -CorbaCFRPort		set _SET=_SQS_CORBA_CFR_PORT&	goto EOP
	if /i %1 EQU -CorbaNDPort		set _SET=_SQS_CORBA_ND_PORT&	goto EOP
	if /i %1 EQU -DomainName		set _SET=_IT_DOMAIN_NAME&		goto EOP
	if /i %1 EQU -ORBdomain_name	set _SET=_IT_DOMAIN_NAME&		goto EOP
	if /i %1 EQU -ProductDir		set _SET=_IT_PRODUCT_DIR&		goto EOP
	if /i %1 EQU -ORBproduct_dir	set _SET=_IT_PRODUCT_DIR&		goto EOP
	if /i %1 EQU -ConfigDir 	    set _SET=_IT_CONFIG_DIR&     	goto EOP
	if /i %1 EQU -ORBconfig_dir     set _SET=_IT_CONFIG_DIR&     	goto EOP
	if /i %1 EQU -ConfigDomainsDir	set _SET=_IT_CONFIG_DOMAINS_DIR&	goto EOP
	if /i %1 EQU -ORBconfig_domains_dir set _SET=_IT_CONFIG_DOMAINS_DIR&	goto EOP
	if /i %1 EQU -ITLicenseFile		set _SET=_IT_LICENSE_FILE&   	goto EOP
	if /i %1 EQU -ORBlicense_file	set _SET=_IT_LICENSE_FILE&   	goto EOP
	if /i %1 EQU -PublishedName		set _SET=SQS_PUBLISHED_NAME&	goto EOP
	if /i %1 EQU -PortRange			set _SET=SQS_PORT_RANGE&		goto EOP
	if /i %1 EQU -Action			set _SET=_SQS_CONFIG_ACTION&   	goto EOP
	if /i %1 EQU -EnvList			set _SET=_SQS_ENV_LIST&			goto EOP
	:: Wird bei Java Clients bentigt, da der Portrange nicht angenommen wird beim ORB init IONA BugID: #71633
	if /i %1 EQU -FixPort			set _SET=_SQS_FIXPORT&			goto EOP
	if /i %1 EQU -NoPortCheck		set NO_PORT_CHECK=1&			goto EOP
	if /i %1 EQU -NetAdapterName	set _SET=_SQS_NET_ADAPTER_NAME&	goto EOP
	if /i %1 EQU -HostnamePolicyShort	set PSQS_HOSTNAME_POLICY=-hostnamePolicy short&goto EOP
	if /i %1 EQU -HostnamePolicyLong	set PSQS_HOSTNAME_POLICY=-hostnamePolicy long&goto EOP
	if /i %1 EQU -HostnamePolicyIP	set PSQS_HOSTNAME_POLICY=-hostnamePolicy ip&goto EOP
	if /i %1 EQU -CorbaLocs			set PSQS_CORBA_LOCS=-corbalocs true&goto EOP
	if /i %1 EQU -Repair			set _SET=_SQS_REPAIR_AS_DB&		goto EOP
	if /i %1 EQU -ObjectThreshold	set _SET=SQS_OBJECT_THRESHOLD&	goto EOP
	if /i %1 EQU -PreferHost		set SQS_PREFER_HOST=1&			goto EOP
	if /i %1 EQU -PreferIP			set SQS_PREFER_IP=1&			goto EOP
	if /i %1 EQU -ResolveIORs		set SQS_SHOW_IORS=1&			goto EOP
	
	:: Parameter zum Setzen der Installflags
	if /i %1 EQU -CorbaInstalled	set CORBA_INSTALLED=1&		goto EOP
	if /i %1 EQU -OODBInstalled		set POET_INSTALLED=1&		goto EOP
	if /i %1 EQU -LicInstalled		set FLEXLM_INSTALLED=1&		goto EOP
	if /i %1 EQU -MSInstalled		set MS_INSTALLED=1&			goto EOP
	if /i %1 EQU -ASInstalled		set AS_INSTALLED=1&			goto EOP
	if /i %1 EQU -APIInstalled		set API_INSTALLED=1&		goto EOP
	if /i %1 EQU -IMP_XMLInstalled	set IMP_XML_INSTALLED=1&	goto EOP

	if /i %1 EQU -CorbaNotInstalled	set CORBA_INSTALLED=0&		goto EOP
	if /i %1 EQU -OODBNotInstalled	set POET_INSTALLED=0&		goto EOP
	if /i %1 EQU -LicNotInstalled	set FLEXLM_INSTALLED=0&		goto EOP
	if /i %1 EQU -MSNotInstalled	set MS_INSTALLED=0&			goto EOP
	if /i %1 EQU -ASNotInstalled	set AS_INSTALLED=0&			goto EOP
	if /i %1 EQU -APINotInstalled	set API_INSTALLED=0&		goto EOP
	if /i %1 EQU -IMP_XMLNotInstalled	set IMP_XML_INSTALLED=0&goto EOP
	if /i %1 EQU -Reconfigure		set _SQS_RECONFIG=1&		goto EOP

	:: Parameter zuerst nur fr den 'ImportXslt' gedacht
	if /i %1 EQU -Workspace			set _SET=_SQS_WORKSPACE&	goto EOP
	if /i %1 EQU -WorkspaceOID		set _SET=_SQS_WORKSPACE_OID&goto EOP
	if /i %1 EQU -ObjectType		set _SET=_SQS_OBJECT_TYPE&	goto EOP
	if /i %1 EQU -ObjectName		set _SET=_SQS_OBJECT_NAME&	goto EOP
	if /i %1 EQU -ObjectOID			set _SET=_SQS_OBJECT_OID&	goto EOP
	if /i %1 EQU -OID				set _SET=_SQS_OID&			goto EOP
	if /i %1 EQU -Mode				set _SET=_SQS_MODE&			goto EOP

	if /i %1 EQU -SessionIOR		set _SET=_SQS_SESSION_IOR&	goto EOP
	if /i %1 EQU -User				set _SET=_SQS_USER&			goto EOP
	if /i %1 EQU -ServiceUser		set _SET=SQS_SERVICE_USER&	goto EOP
	if /i %1 EQU -PW	 			set _SET=SQS_PW&			goto EOP
	if /i %1 EQU -PassWd 			set _SET=SQS_PW&			goto EOP
	if /i %1 EQU -DependOnService	set _SET=SQS_DEPENDENCIES&	goto EOP
	if /i %1 EQU -AutoStart			set _SET=SQS_AUTO_START&	goto EOP
	if /i %1 EQU -EvtLevel			set _SET=SQS_EVT_LEVEL&		goto EOP
	if /i %1 EQU -prepare			set _SET=_SQS_PREPARE&		goto EOP
	if /i %1 EQU -install			set _SET=SQS_INSTALL&		goto EOP
	if /i %1 EQU -uninstall			set _SET=SQS_UNINSTALL&		goto EOP
	if /i %1 EQU -verbose			set _SET=SQS_VERBOSE&		goto EOP
	if /i %1 EQU -v					set SQS_VERBOSE=1&			goto EOP
	if /i %1 EQU -version			set SQS_VERBOSE=1&			goto EOP
	if /i %1 EQU -all				set _SET=SQS_ALL&			goto EOP
	if /i %1 EQU -UserEnv			set _SQS_USER_ENV=1&		goto EOP
	if /i %1 EQU -MachineEnv		set _SQS_MACHINE_ENV=1&		goto EOP
	if /i %1 EQU -VolatileEnv		set _SQS_VOLATILE_ENV=1&	goto EOP
	if /i %1 EQU -DefaultEnv		set _SQS_DEFAULT_ENV=1&		goto EOP
	if /i %1 EQU -DeleteEnv			set _SQS_DELETE_ENV=1&		goto EOP
	if /i %1 EQU -RegisterIT		set _SQS_REGISTER_IT=1&		goto EOP
	if /i %1 EQU -Register-tlog		set _SQS_REGISTER_TLOG=1&	goto EOP
	if /i %1 EQU -Unregister-tlog	set _SQS_UNREGISTER_TLOG=1&	goto EOP
	if /i %1 EQU -TPAServer			set _SET=_SQS_TPA_SERVER&	goto EOP
	if /i %1 EQU -ConfigTPAServer	set _SQS_CONFIGURE_TPA_SERVER=1&goto EOP
	if /i %1 EQU -IgnoreCORBAProblem set _SQS_IGNORE_CORBA_PROBLEM=1&goto EOP
	if /i %1 EQU -IniFile			set _SET=_SQS_INI_FILE&			goto EOP
	if /i %1 EQU -BatchMode			set SQS_BATCH_MODE=%1&			goto EOP
	if /i %1 EQU -FeatureList		set _SET=_SQS_FEATURE_LIST&		goto EOP
	if /i %1 EQU -NewRecoveryDir	set _SET=_SQS_NEW_RECOVERY_PATH&goto EOP
	if /i %1 EQU -ShowMultipleReferences set _SET=_SQS_SHOW_MULTIPLE_REFERENCES&goto EOP
	if /i %1 EQU -JavaVMMinHeap		set _SET=_SQS_JAVA_VM_MIN_HEAP&	goto EOP
	if /i %1 EQU -JavaVMMaxHeap		set _SET=_SQS_JAVA_VM_MAX_HEAP&	goto EOP
	if /i %1 EQU -JavaVMStackSize	set _SET=_SQS_JAVA_VM_STACKSIZE&goto EOP
	if /i %1 EQU -StopEnv			set SQS_STOPENV=1&				goto EOP
	if /i %1 EQU -Deps				if "%CheckDependencies%" EQU "0" set CheckDependencies=1&		goto EOP
	if /i %1 EQU -PyScript			set _SET=SQS_PY_SCRIPT&			goto EOP
	
	:: in diesem Skript oder als Benutzer- oder Systemvariable oder auch im 
	:: zentralen Batch "Environment-Defaults.bat". ber den Parameter 
	:: ============================================================================
	:: Falls der Parameter nicht erkannt wurde, in "_SQS_ADD_PARAMS" merken!
	:: ============================================================================
	call :Debug : Add %1 to '%_SQS_ADD_PARAMS%'
	if defined _SQS_ADD_PARAMS set _SQS_ADD_PARAMS=%_SQS_ADD_PARAMS% %1
	if not defined _SQS_ADD_PARAMS set _SQS_ADD_PARAMS=%1
	:EOP

	set _ENV_VAR=
	if defined _SET set _ENV_VAR= (Used var: %_SET%)
	if defined _IS_OPTION     call :Debug : Option: %1%_ENV_VAR%
	if not defined _IS_OPTION call :Debug : Value : %1
goto :EOF

:: ==================================================================
:RemoveLeadingZeros
	if "%~1" EQU "0" set %2=%~1&goto :EOF
	set s_=%~1
	:: Einstiegstest
	if "%s_:~0,1%" NEQ "0" set %2=%s_%&goto :EOF
	:loop
	set s_=%s_:*0=%
	if "%s_:~0,1%"=="0" goto loop
	set %2=%s_%
goto :EOF

:: ==================================================================
:: Hilfsfunktionen:
:: * Check* berprfen ob Parameter 2 existiert und setzen %1 auf
::   den nicht gequoteten Wert
:: * Anzeigefunktionen
::   Geben die bergebenen Parameter aus, wenn der Filter es zulsst
:: * File kopieren
::   Kopiert mit Umlenkung der Standardausgaben
:: ==================================================================
:Output
	if "%~1" EQU ".leer" echo.&goto :EOF
	if "%~2" EQU "RMQuotes" echo %~1&goto :EOF
	echo %*	
goto :EOF

:Info
	if defined _SQS_SILENT goto :EOF
	if "%~1" EQU "" echo Empty info message!&goto :EOF
	call :Output %*
goto :EOF

:Debug
	if not defined _SQS_DEBUG goto :EOF
	if "%~1" EQU "" echo Empty debug message!&goto :EOF
	call :Output %*
goto :EOF

:WARNING
	if not defined _SQS_SHOW_WARNIG goto :EOF
	if "%~1" EQU "" echo Empty warning message!&goto :EOF
	call :Output %*
goto :EOF

:ERROR
	if "%~1" EQU "" echo Empty error message!&goto :EOF
	call :Output %*
goto :EOF

:DebugHeader
	call :Debug .leer
	call :Debug : ============================================================================
	call :Debug : Section '%*'
goto :EOF
